import { db } from '../models';

const PgBoss = require('pg-boss');

export const boss = new PgBoss({
  db: {
    executeSql: async (query: string, originalValues: Array<string | number | boolean> = []) => {
      const text = query.replace(/\$(\d)/g, ':$1');
      const values = originalValues.reduce(
        (result: any, value: any, index: number) => (
          { ...result, [`${index + 1}`]: value }
        ),
        {},
      );
      return db.raw(text, values);
    },
  },
});

export const bossReady = boss.start();

export async function enqueue(
  task: string,
  args: Array<string | number>,
  queue: string = 'common',
) {
  await bossReady;
  return boss.publish(queue, { task, args }, { retryLimit: 2 });
}

export function batchedEnqueue(
  tasks: Array<{task: string, args: Array<string | number>}>,
  queue: string = 'common',
) {
  return tasks.map(({ task, args }) => enqueue(task, args, queue));
}
