import { log, reportError } from './utils';
import { boss, bossReady } from '../components/queues';
import executeTask from '../components/tasks-executer';

interface QueueJob {
  name: string;
  data: {
    task: string;
    args: Array<string | number>;
  };
}

function taskRunner(job: QueueJob) {
  return executeTask(job.data.task, job.data.args)
    .catch((error: Error) => {
      reportError(error, {
        message: 'Error during task processing',
        extra: {
          task: job.data.task,
          args: job.data.args,
        },
      });
      throw error;
    });
}

export default async function runWorker() {
  log('Initiating worker process');

  await bossReady;

  boss.on('error', (error: Error) => {
    reportError(error, {
      message: 'Error during task processing',
    });
  });

  await boss.subscribe('common', {
    teamSize: 4,
    teamConcurrency: 4,
  }, taskRunner);
  await boss.subscribe('import', {
    teamSize: 4,
    teamConcurrency: 4,
  }, taskRunner);

  log('Worker initiated');
}
