require('dotenv').config();

/* eslint-disable import/first */

import runConsole from './components/console';
import executeTask from './components/tasks-executer';
import generateServer from './core/express';
import { log } from './core/utils';
import runWorker from './core/worker';
import schedule from './components/scheduler';

require('source-map-support').install();

const action = process.argv[2] || 'server';

function runServer(): void {
  const port = Number(process.env.PORT) || 4444;
  const listen = generateServer();
  listen(port);
  log('Server is listening');
}

switch (action) {
  case 'server':
    runServer();
    break;
  case 'console':
    runConsole().catch(console.error);
    break;
  case 'execute':
    executeTask(process.argv[3], process.argv.slice(4), true)
      .catch((error: Error) => {
        console.error(error);
        process.nextTick(() => process.exit());
      });
    break;
  case 'worker':
    runWorker();
    break;
  case 'schedule':
    schedule(process.argv[3], process.argv[4], process.argv.slice(5));
    break;
  default:
    throw new Error(`Unknown action "${action}"`);
}
