'use strict';

Object.defineProperty(exports, '__esModule', { value: true });
const Discord = require('discord.js');
const utils_1 = require('../core/utils');
const { WikidotUser, db } = require('../models');

const discord = new Discord.Client();
const token = process.env.DISCORD_BOT_TOKEN;
const SCP_RU_GUILD_ID = '106464299056128000';
const MEMBERS_ROLE_ID = '106465861476319232';
function run() {
  return new Promise((resolve) => {
    discord.on('ready', () => {
      const guild = discord.guilds.find((data, key) => key === SCP_RU_GUILD_ID);
      const memberRole = guild.roles.find(role => role.id === MEMBERS_ROLE_ID);
      utils_1.logImportant('Initiating Discord roles sync');
      let numberOfMembersToSync;
      WikidotUser.membersWithDiscordTag()
        .then((memberDiscordIDs) => {
          const usersToUpdate = guild.members.filterArray((member) => {
            const { user } = member;
            const userId = `${user.username}#${user.discriminator}`;
            return memberDiscordIDs.includes(userId) && !member.roles.has(MEMBERS_ROLE_ID);
          });
          numberOfMembersToSync = usersToUpdate.length;
          if (numberOfMembersToSync) {
            utils_1.logImportant(`Adding roles: ${numberOfMembersToSync}`);
          } else {
            utils_1.logImportant('Everything is in sync');
          }
          return usersToUpdate;
        })
        .map((userToUpdate) => {
          utils_1.logImportant(`Adding role to user \`${userToUpdate.user.username}\``);
          return userToUpdate.addRole(memberRole);
        })
        .then(() => {
          if (numberOfMembersToSync) {
            utils_1.logImportant(`Synced discord roles for ${numberOfMembersToSync} user(s)`);
          }
          resolve();
        })
        .catch((error) => {
          utils_1.reportError(error, { message: 'Error setting discord member roles' });
          resolve();
        });
    });
    discord.login(token);
  });
}
exports.default = run;
// # sourceMappingURL=discord-roles-sync.js.map
