"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const models_1 = require("../models");
const utils_1 = require("../core/utils");
const wikidot_kit_1 = require("../components/wikidot-kit");
const PAGE_NAME_BLACKLIST = /^(admin|nav|css|system):/;
function run(wikiName, pageName) {
    if (!(wikiName && pageName)) {
        throw new Error('Wiki name & page name are required');
    }
    utils_1.log(`Importing page ${wikiName}/${pageName}`);
    const wikiUrl = wikidot_kit_1.SITES[wikiName].url;
    if (PAGE_NAME_BLACKLIST.test(pageName)) {
        return Promise.resolve();
    }
    return wikidot_kit_1.wk.fetchPage(wikiName, pageName)
        .catch((error) => {
        utils_1.reportError(error, { message: 'Error importing page', extra: { wikiName, pageName } });
    })
        .then((data) => models_1.WikidotPage.upsert({
        wikiName,
        name: pageName,
        title: data.title,
        content: data.content,
        tags: data.tags,
        rating: data.rating,
        html: data.html,
        createdAt: data.created_at,
        createdBy: data.created_by,
        updatedAt: data.updated_at,
        updatedBy: data.updated_by,
    }))
        .then(() => wikidot_kit_1.wk.fetchPageVotes(wikiUrl, pageName))
        .then((votes) => {
        utils_1.log(`Imported votes for ${wikiName}/${pageName}`, { extra: votes });
        return models_1.WikidotPage.upsert({
            wikiName,
            name: pageName,
            votes: JSON.stringify(votes),
        });
    })
        .then(() => {
        utils_1.log(`[DONE] ${wikiName}/${pageName}`);
    })
        .catch((error) => {
        utils_1.reportError(error, { message: 'Error saving page', extra: { wikiName, pageName } });
    });
}
exports.default = run;
//# sourceMappingURL=page-import.js.map